==> ejc-credentials-impl-3.0.0-20220523.080402-30-sources.jar: com/ejianc/certify/bean/CorpCertifHEntity.java <==
package com.ejianc.certify.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 证件借用配件-表头
 * 
 * @author generator
 * 
 */
 @TableName("jzctm_corpcertify")
public class CorpCertifHEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="approver")
    private Long approver; // 审批人
    @TableField(value="taudittime")
    private String taudittime; // 审批时间
    @TableField(value="vapprovenote")
    private String vapprovenote; // 审批附言
    @TableField(value="fstatusflag")
    private Integer fstatusflag; // 单据状态
    @TableField(value="pk_billtype")
    private Long pkBilltype; // 单据类型
    @TableField(value="ts")
    private Date ts; // 时间戳
    @TableField(value="vbusitype")
    private String vbusitype; // 业务类型（1-项目报建 2-工程投标 3-区域备案）
    @TableField(value="pk_group")
    private String pkGroup; // 集团
    @TableField(value="pk_org")
    private Long pkOrg; // 组织
    @TableField(value="pk_dept")
    private Long pkDept; // 部门
    @TableField(value="vbillcode")
    private String vbillcode; // 单据编号
    @TableField(value="dbilldate")
    private String dbilldate; // 单据日期
    @TableField(value="vmemo")
    private String vmemo; // 备注
    @TableField(value="pk_pjr")
    private Long pkPjr; // 配件人
    @TableField(value="pk_corpcertifapply")
    private Long pkCorpcertifapply; // 证件借用申请单
    @TableField(value="fqr_org")
    private Long fqrOrg; // 发起人组织
    @TableField(value="fqr_dept")
    private Long fqrDept; // 发起人部门
    @TableField(value="pk_fqr")
    private Long pkFqr; // 发起人
    @TableField(value="applyer_tel")
    private String applyerTel; // 发起人电话
    @TableField(value="applydate")
    private String applydate; // 发起时间
    @TableField(value="applyreason")
    private String applyreason; // 用途
    @TableField(value="pk_project")
    private Long pkProject; // 报建立项
    @TableField(value="pk_contract")
    private Long pkContract; // 报建合同
    @TableField(value="pk_pmproject")
    private Long pkPmproject; // 施工项目立项
    @TableField(value="pk_pmproject_jlb")
    private Long pkPmprojectJlb; // 项目经理部
    @TableField(value="project_finish_time")
    private String projectFinishTime; // 项目预计竣工时间
    @TableField(value="vdef1")
    private String vdef1; // 
    @TableField(value="vdef10")
    private String vdef10; // 
    @TableField(value="vdef2")
    private String vdef2; // 
    @TableField(value="vdef3")
    private String vdef3; // 
    @TableField(value="vdef4")
    private String vdef4; // 
    @TableField(value="vdef5")
    private String vdef5; // 
    @TableField(value="vdef6")
    private String vdef6; // 
    @TableField(value="vdef7")
    private String vdef7; // 
    @TableField(value="vdef8")
    private String vdef8; // 
    @TableField(value="vdef9")
    private String vdef9; // 
    @TableField(value="bill_state")
    private Long billState; // 单据状态
    
    
    

    public Long getApprover() {
        return approver;
    }

    public void setApprover(Long approver) {
        this.approver = approver;
    }
    public String getTaudittime() {
        return taudittime;
    }

    public void setTaudittime(String taudittime) {
        this.taudittime = taudittime;
    }
    public String getVapprovenote() {
        return vapprovenote;
    }

    public void setVapprovenote(String vapprovenote) {
        this.vapprovenote = vapprovenote;
    }
    public Integer getFstatusflag() {
        return fstatusflag;
    }

    public void setFstatusflag(Integer fstatusflag) {
        this.fstatusflag = fstatusflag;
    }
    public Long getPkBilltype() {
        return pkBilltype;
    }

    public void setPkBilltype(Long pkBilltype) {
        this.pkBilltype = pkBilltype;
    }
    public Date getTs() {
        return ts;
    }

    public void setTs(Date ts) {
        this.ts = ts;
    }
    public String getVbusitype() {
        return vbusitype;
    }

    public void setVbusitype(String vbusitype) {
        this.vbusitype = vbusitype;
    }
    public String getPkGroup() {
        return pkGroup;
    }

    public void setPkGroup(String pkGroup) {
        this.pkGroup = pkGroup;
    }
    public Long getPkOrg() {
        return pkOrg;
    }

    public void setPkOrg(Long pkOrg) {
        this.pkOrg = pkOrg;
    }
    public Long getPkDept() {
        return pkDept;
    }

    public void setPkDept(Long pkDept) {
        this.pkDept = pkDept;
    }
    public String getVbillcode() {
        return vbillcode;
    }

    public void setVbillcode(String vbillcode) {
        this.vbillcode = vbillcode;
    }
    public String getDbilldate() {
        return dbilldate;
    }

    public void setDbilldate(String dbilldate) {
        this.dbilldate = dbilldate;
    }
    public String getVmemo() {
        return vmemo;
    }

    public void setVmemo(String vmemo) {
        this.vmemo = vmemo;
    }
    public Long getPkPjr() {
        return pkPjr;
    }

    public void setPkPjr(Long pkPjr) {
        this.pkPjr = pkPjr;
    }
    public Long getPkCorpcertifapply() {
        return pkCorpcertifapply;
    }

    public void setPkCorpcertifapply(Long pkCorpcertifapply) {
        this.pkCorpcertifapply = pkCorpcertifapply;
    }
    public Long getFqrOrg() {
        return fqrOrg;
    }

    public void setFqrOrg(Long fqrOrg) {
        this.fqrOrg = fqrOrg;
    }
    public Long getFqrDept() {
        return fqrDept;
    }

    public void setFqrDept(Long fqrDept) {
        this.fqrDept = fqrDept;
    }
    public Long getPkFqr() {
        return pkFqr;
    }

    public void setPkFqr(Long pkFqr) {
        this.pkFqr = pkFqr;
    }
    public String getApplyerTel() {
        return applyerTel;
    }

    public void setApplyerTel(String applyerTel) {
        this.applyerTel = applyerTel;
    }
    public String getApplydate() {
        return applydate;
    }

    public void setApplydate(String applydate) {
        this.applydate = applydate;
    }
    public String getApplyreason() {
        return applyreason;
    }

    public void setApplyreason(String applyreason) {
        this.applyreason = applyreason;
    }
    public Long getPkProject() {
        return pkProject;
    }

    public void setPkProject(Long pkProject) {
        this.pkProject = pkProject;
    }
    public Long getPkContract() {
        return pkContract;
    }

    public void setPkContract(Long pkContract) {
        this.pkContract = pkContract;
    }
    public Long getPkPmproject() {
        return pkPmproject;
    }

    public void setPkPmproject(Long pkPmproject) {
        this.pkPmproject = pkPmproject;
    }
    public Long getPkPmprojectJlb() {
        return pkPmprojectJlb;
    }

    public void setPkPmprojectJlb(Long pkPmprojectJlb) {
        this.pkPmprojectJlb = pkPmprojectJlb;
    }
    public String getProjectFinishTime() {
        return projectFinishTime;
    }

    public void setProjectFinishTime(String projectFinishTime) {
        this.projectFinishTime = projectFinishTime;
    }
    public String getVdef1() {
        return vdef1;
    }

    public void setVdef1(String vdef1) {
        this.vdef1 = vdef1;
    }
    public String getVdef10() {
        return vdef10;
    }

    public void setVdef10(String vdef10) {
        this.vdef10 = vdef10;
    }
    public String getVdef2() {
        return vdef2;
    }

    public void setVdef2(String vdef2) {
        this.vdef2 = vdef2;
    }
    public String getVdef3() {
        return vdef3;
    }

    public void setVdef3(String vdef3) {
        this.vdef3 = vdef3;
    }
    public String getVdef4() {
        return vdef4;
    }

    public void setVdef4(String vdef4) {
        this.vdef4 = vdef4;
    }
    public String getVdef5() {
        return vdef5;
    }

    public void setVdef5(String vdef5) {
        this.vdef5 = vdef5;
    }
    public String getVdef6() {
        return vdef6;
    }

    public void setVdef6(String vdef6) {
        this.vdef6 = vdef6;
    }
    public String getVdef7() {
        return vdef7;
    }

    public void setVdef7(String vdef7) {
        this.vdef7 = vdef7;
    }
    public String getVdef8() {
        return vdef8;
    }

    public void setVdef8(String vdef8) {
        this.vdef8 = vdef8;
    }
    public String getVdef9() {
        return vdef9;
    }

    public void setVdef9(String vdef9) {
        this.vdef9 = vdef9;
    }
    public Long getBillState() {
        return billState;
    }

    public void setBillState(Long billState) {
        this.billState = billState;
    }
    
}

==> ejc-credentials-impl-3.0.0-20220608.033454-41-sources.jar: com/ejianc/certify/bean/CorpCertifHEntity.java <==
package com.ejianc.certify.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 证件借用配件-表头
 * 
 * @author generator
 * 
 */
 @TableName("jzctm_corpcertify")
public class CorpCertifHEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="approver")
    private Long approver; // 审批人
    @TableField(value="taudittime")
    private String taudittime; // 审批时间
    @TableField(value="vapprovenote")
    private String vapprovenote; // 审批附言
    @TableField(value="pk_billtype")
    private Long pkBilltype; // 单据类型
    @TableField(value="ts")
    private Date ts; // 时间戳
    @TableField(value="vbusitype")
    private String vbusitype; // 业务类型（1-项目报建 2-工程投标 3-区域备案）
    @TableField(value="pk_group")
    private String pkGroup; // 集团
    @TableField(value="pk_org")
    private Long pkOrg; // 组织
    @TableField(value="pk_dept")
    private Long pkDept; // 部门
    @TableField(value="vbillcode")
    private String vbillcode; // 单据编号
    @TableField(value="dbilldate")
    private String dbilldate; // 单据日期
    @TableField(value="vmemo")
    private String vmemo; // 备注
    @TableField(value="pk_pjr")
    private Long pkPjr; // 配件人
    @TableField(value="pk_corpcertifapply")
    private Long pkCorpcertifapply; // 证件借用申请单
    @TableField(value="fqr_org")
    private Long fqrOrg; // 发起人组织
    @TableField(value="fqr_dept")
    private Long fqrDept; // 发起人部门
    @TableField(value="pk_fqr")
    private Long pkFqr; // 发起人
    @TableField(value="applyer_tel")
    private String applyerTel; // 发起人电话
    @TableField(value="applydate")
    private String applydate; // 发起时间
    @TableField(value="applyreason")
    private String applyreason; // 用途
    @TableField(value="pk_project")
    private Long pkProject; // 报建立项
    @TableField(value="pk_contract")
    private Long pkContract; // 报建合同
    @TableField(value="pk_pmproject")
    private Long pkPmproject; // 施工项目立项
    @TableField(value="pk_pmproject_jlb")
    private Long pkPmprojectJlb; // 项目经理部
    @TableField(value="project_finish_time")
    private String projectFinishTime; // 项目预计竣工时间
    @TableField(value="pk_specialreq")
    private Long pkSpecialreq;
    @TableField(value="vdef1")
    private String vdef1; // 
    @TableField(value="vdef10")
    private String vdef10; // 
    @TableField(value="vdef2")
    private String vdef2; // 
    @TableField(value="vdef3")
    private String vdef3; // 
    @TableField(value="vdef4")
    private String vdef4; // 
    @TableField(value="vdef5")
    private String vdef5; // 
    @TableField(value="vdef6")
    private String vdef6; // 
    @TableField(value="vdef7")
    private String vdef7; // 
    @TableField(value="vdef8")
    private String vdef8; // 
    @TableField(value="vdef9")
    private String vdef9; // 
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="isfk")
    private String isfk;

    @TableField(exist = false)
    @SubEntity(serviceName = "corpCertifBService", pidName = "pkCorpcertify")
    private List<CorpCertifBEntity> corpCertifBVOList = new ArrayList<>();

    @TableField(exist = false)
    @SubEntity(serviceName = "corpCertifFService", pidName = "pkCorpcertify")
    private List<CorpCertifFEntity> corpCertifFVOList = new ArrayList<>();

    public List<CorpCertifBEntity> getCorpCertifBVOList() {
        return corpCertifBVOList;
    }
    public Long getPkSpecialreq() {
        return pkSpecialreq;
    }

    public void setPkSpecialreq(Long pkSpecialreq) {
        this.pkSpecialreq = pkSpecialreq;
    }

    public String getIsfk() {
        return isfk;
    }

    public void setIsfk(String isfk) {
        this.isfk = isfk;
    }
    public void setCorpCertifBVOList(List<CorpCertifBEntity> corpCertifBVOList) {
        this.corpCertifBVOList = corpCertifBVOList;
    }

    public List<CorpCertifFEntity> getCorpCertifFVOList() {
        return corpCertifFVOList;
    }

    public void setCorpCertifFVOList(List<CorpCertifFEntity> corpCertifFVOList) {
        this.corpCertifFVOList = corpCertifFVOList;
    }

    public Long getApprover() {
        return approver;
    }

    public void setApprover(Long approver) {
        this.approver = approver;
    }
    public String getTaudittime() {
        return taudittime;
    }

    public void setTaudittime(String taudittime) {
        this.taudittime = taudittime;
    }
    public String getVapprovenote() {
        return vapprovenote;
    }

    public void setVapprovenote(String vapprovenote) {
        this.vapprovenote = vapprovenote;
    }

    public Long getPkBilltype() {
        return pkBilltype;
    }

    public void setPkBilltype(Long pkBilltype) {
        this.pkBilltype = pkBilltype;
    }
    public Date getTs() {
        return ts;
    }

    public void setTs(Date ts) {
        this.ts = ts;
    }
    public String getVbusitype() {
        return vbusitype;
    }

    public void setVbusitype(String vbusitype) {
        this.vbusitype = vbusitype;
    }
    public String getPkGroup() {
        return pkGroup;
    }

    public void setPkGroup(String pkGroup) {
        this.pkGroup = pkGroup;
    }
    public Long getPkOrg() {
        return pkOrg;
    }

    public void setPkOrg(Long pkOrg) {
        this.pkOrg = pkOrg;
    }
    public Long getPkDept() {
        return pkDept;
    }

    public void setPkDept(Long pkDept) {
        this.pkDept = pkDept;
    }
    public String getVbillcode() {
        return vbillcode;
    }

    public void setVbillcode(String vbillcode) {
        this.vbillcode = vbillcode;
    }
    public String getDbilldate() {
        return dbilldate;
    }

    public void setDbilldate(String dbilldate) {
        this.dbilldate = dbilldate;
    }
    public String getVmemo() {
        return vmemo;
    }

    public void setVmemo(String vmemo) {
        this.vmemo = vmemo;
    }
    public Long getPkPjr() {
        return pkPjr;
    }

    public void setPkPjr(Long pkPjr) {
        this.pkPjr = pkPjr;
    }
    public Long getPkCorpcertifapply() {
        return pkCorpcertifapply;
    }

    public void setPkCorpcertifapply(Long pkCorpcertifapply) {
        this.pkCorpcertifapply = pkCorpcertifapply;
    }
    public Long getFqrOrg() {
        return fqrOrg;
    }

    public void setFqrOrg(Long fqrOrg) {
        this.fqrOrg = fqrOrg;
    }
    public Long getFqrDept() {
        return fqrDept;
    }

    public void setFqrDept(Long fqrDept) {
        this.fqrDept = fqrDept;
    }
    public Long getPkFqr() {
        return pkFqr;
    }

    public void setPkFqr(Long pkFqr) {
        this.pkFqr = pkFqr;
    }
    public String getApplyerTel() {
        return applyerTel;
    }

    public void setApplyerTel(String applyerTel) {
        this.applyerTel = applyerTel;
    }
    public String getApplydate() {
        return applydate;
    }

    public void setApplydate(String applydate) {
        this.applydate = applydate;
    }
    public String getApplyreason() {
        return applyreason;
    }

    public void setApplyreason(String applyreason) {
        this.applyreason = applyreason;
    }
    public Long getPkProject() {
        return pkProject;
    }

    public void setPkProject(Long pkProject) {
        this.pkProject = pkProject;
    }
    public Long getPkContract() {
        return pkContract;
    }

    public void setPkContract(Long pkContract) {
        this.pkContract = pkContract;
    }
    public Long getPkPmproject() {
        return pkPmproject;
    }

    public void setPkPmproject(Long pkPmproject) {
        this.pkPmproject = pkPmproject;
    }
    public Long getPkPmprojectJlb() {
        return pkPmprojectJlb;
    }

    public void setPkPmprojectJlb(Long pkPmprojectJlb) {
        this.pkPmprojectJlb = pkPmprojectJlb;
    }
    public String getProjectFinishTime() {
        return projectFinishTime;
    }

    public void setProjectFinishTime(String projectFinishTime) {
        this.projectFinishTime = projectFinishTime;
    }
    public String getVdef1() {
        return vdef1;
    }

    public void setVdef1(String vdef1) {
        this.vdef1 = vdef1;
    }
    public String getVdef10() {
        return vdef10;
    }

    public void setVdef10(String vdef10) {
        this.vdef10 = vdef10;
    }
    public String getVdef2() {
        return vdef2;
    }

    public void setVdef2(String vdef2) {
        this.vdef2 = vdef2;
    }
    public String getVdef3() {
        return vdef3;
    }

    public void setVdef3(String vdef3) {
        this.vdef3 = vdef3;
    }
    public String getVdef4() {
        return vdef4;
    }

    public void setVdef4(String vdef4) {
        this.vdef4 = vdef4;
    }
    public String getVdef5() {
        return vdef5;
    }

    public void setVdef5(String vdef5) {
        this.vdef5 = vdef5;
    }
    public String getVdef6() {
        return vdef6;
    }

    public void setVdef6(String vdef6) {
        this.vdef6 = vdef6;
    }
    public String getVdef7() {
        return vdef7;
    }

    public void setVdef7(String vdef7) {
        this.vdef7 = vdef7;
    }
    public String getVdef8() {
        return vdef8;
    }

    public void setVdef8(String vdef8) {
        this.vdef8 = vdef8;
    }
    public String getVdef9() {
        return vdef9;
    }

    public void setVdef9(String vdef9) {
        this.vdef9 = vdef9;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    
}
